@@ -57,7 +57,7 @@ use PPIx::Regexp::Util qw{
 
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.071';
+our $VERSION = '0.075';
 
 our $DEFAULT_POSTDEREF;
 defined $DEFAULT_POSTDEREF
@@ -130,6 +130,9 @@ defined $DEFAULT_POSTDEREF
 		return;
 	    };
 
+	defined $args{postderef}
+	    and __PACKAGE__->_deprecation_notice( attribute => 'postderef' );
+
 	my $self = {
 	    index_locations => $args{index_locations},	# Index locations
 	    capture => undef,	# Captures from find_regexp.
@@ -157,8 +160,7 @@ defined $DEFAULT_POSTDEREF
 	    modifiers => [{}],	# Modifier hash.
 	    pending => [],	# Tokens made but not returned.
 	    postderef => defined $args{postderef} ?
-		$args{postderef} :
-		$DEFAULT_POSTDEREF,
+		$args{postderef} : 1,
 	    prior => TOKEN_UNKNOWN,	# Prior significant token.
 	    source => $re,	# The object we were initialized with.
 	    strict => $args{strict},	# like "use re 'strict';".
@@ -751,15 +753,11 @@ sub tokens {
 #	This method returns true if the deprecation is in progress. In
 #	fact it returns the deprecation level.
 
-=begin comment
-
 {
 
     my %deprecate = (
 	attribute => {
-	},
-	method => {
-	    prior	=> 3,
+	    postderef	=> 1,
 	},
     );
 
@@ -780,18 +778,20 @@ sub tokens {
 	return;
     }
 
+=begin comment
+
     sub _deprecation_in_progress {
 	my ( $self, $type, $name ) = @_;
 	$deprecate{$type} or return;
 	return $deprecate{$type}{$name};
     }
 
-}
-
 =end comment
 
 =cut
 
+}
+
 sub _remainder {
     my ( $self ) = @_;
 
@@ -1319,6 +1319,9 @@ are to be computed.
 
 =item postderef boolean
 
+B<THIS ARGUMENT IS DEPRECATED>.
+See L<DEPRECATION NOTICE|PPIx::Regexp/DEPRECATION NOTICE> in L<PPIx::Regexp|PPIx::Regexp> for the details.
+
 This option specifies whether the tokenizer recognizes postfix
 dereferencing. See the L<PPIx::Regexp|PPIx::Regexp>
 L<new()|PPIx::Regexp/new> documentation for the details.
